"dbern" <-

function(x, prob, log = FALSE)



{



	dbinom(x,size=1,prob=prob,log=log)

	

}

